#Counter BIN forward 
-Bits[1..36]
-Taktflanke[1,0]
<
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity |Name| is
    Port ( takt : in std_logic;
           q : out std_logic_vector(|Bits-| downto 0));
end |Name|;

architecture Behavioral of |Name| is
signal qi : std_logic_vector(|Bits-| downto 0);
begin
  
  ct: PROCESS (takt)
      BEGIN
        IF takt'event and takt='|Taktflanke|' 
	        THEN qi <= qi + 1; END IF;
      END PROCESS ct;

  q <= qi;
end Behavioral;
>


#Counter BIN forward with async Reset
-Bits[1..36]
-Taktflanke[1,0]
-Reset[1,0]
<
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity |Name| is
    Port ( takt : in std_logic;
           reset : in std_logic;
           q : out std_logic_vector(|Bits-| downto 0));
end |Name|;

architecture Behavioral of |Name| is
signal qi : std_logic_vector(|Bits-| downto 0);
begin
  
  ct: PROCESS (takt,reset)
      BEGIN
        IF reset='|Reset|' THEN qi <= (OTHERS => '0');
	  ELSIF takt'event and takt='|Taktflanke|' 
	        THEN qi <= qi + 1; 
	END IF;
      END PROCESS ct;

  q <= qi;
end Behavioral;
>


#Counter BIN forward with async Reset, sync Load
-Bits[1..36]
-Taktflanke[1,0]
-Reset[1,0]
-Load[1,0]
<
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity |Name| is
    Port ( takt : in std_logic;
           reset : in std_logic;
           load : in std_logic;
           d : in std_logic_vector(|Bits-| downto 0);
           q : out std_logic_vector(|Bits-| downto 0));
end |Name|;

architecture Behavioral of |Name| is
signal qi : std_logic_vector(|Bits-| downto 0);
begin
  
  ct: PROCESS (takt,reset,load,d)
      BEGIN
        IF reset='|Reset|' THEN qi <= (OTHERS => '0');
          ELSIF takt'event and takt='|Taktflanke|' 
	      THEN IF load='|Load|' THEN qi <= d; 
		                    ELSE qi <= qi + 1; END IF;
	END IF;
      END PROCESS ct;

  q <= qi;
end Behavioral;
>


#Counter BIN forward, Enable 
-Bits[1..36]
-Taktflanke[1,0]
-Enable[1,0]
<
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity |Name| is
    Port ( takt : in std_logic;
           enable : in std_logic;
           q : out std_logic_vector(|Bits-| downto 0));
end |Name|;

architecture Behavioral of |Name| is
signal qi : std_logic_vector(|Bits-| downto 0);
begin
  
  ct: PROCESS (takt,enable)
      BEGIN
        IF takt'event and takt='|Taktflanke|' THEN 
	   IF enable = '|enable|' THEN qi <= qi + 1; END IF;
        END IF;
      END PROCESS ct;

  q <= qi;
end Behavioral;
>


#Counter BIN forward with async Reset, Enable
-Bits[1..36]
-Taktflanke[1,0]
-Reset[1,0]
-Enable[1,0]
<
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity |Name| is
    Port ( takt : in std_logic;
           reset : in std_logic;
           enable : in std_logic;
           q : out std_logic_vector(|Bits-| downto 0));
end |Name|;

architecture Behavioral of |Name| is
signal qi : std_logic_vector(|Bits-| downto 0);
begin
  
  ct: PROCESS (takt,reset,enable)
      BEGIN
        IF reset='|Reset|' THEN qi <= (OTHERS => '0');
	  ELSIF takt'event and takt='|Taktflanke|' THEN
	        IF enable = '|Enable|' THEN qi <= qi + 1; END IF;
	END IF;
      END PROCESS ct;

  q <= qi;
end Behavioral;
>


#Counter BIN forward with async Reset, sync Load, Enable
-Bits[1..36]
-Taktflanke[1,0]
-Reset[1,0]
-Load[1,0]
-Enable[1,0]
<
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity |Name| is
    Port ( takt : in std_logic;
           reset : in std_logic;
           load : in std_logic;
           enable : in std_logic;
           d : in std_logic_vector(|Bits-| downto 0);
           q : out std_logic_vector(|Bits-| downto 0));
end |Name|;

architecture Behavioral of |Name| is
signal qi : std_logic_vector(|Bits-| downto 0);
begin
  
  ct: PROCESS (takt,reset,load,enable,d)
      BEGIN
        IF reset='|Reset|' THEN qi <= (OTHERS => '0');
          ELSIF takt'event and takt='|Taktflanke|' THEN 
	        IF enable = '|Eable|' THEN
                   IF load='|Load|' THEN qi <= d; 
                                    ELSE qi <= qi + 1; END IF;
                END IF;  
	END IF;
      END PROCESS ct;

  q <= qi;
end Behavioral;
>


#Counter BIN revers 
-Bits[1..36]
-Taktflanke[1,0]
<
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity |Name| is
    Port ( takt : in std_logic;
           q : out std_logic_vector(|Bits-| downto 0));
end |Name|;

architecture Behavioral of |Name| is
signal qi : std_logic_vector(|Bits-| downto 0);
begin
  
  ct: PROCESS (takt)
      BEGIN
        IF takt'event and takt='|Taktflanke|' 
	        THEN qi <= qi - 1; END IF;
      END PROCESS ct;

  q <= qi;
end Behavioral;
>


#Counter BIN revers with async Reset
-Bits[1..36]
-Taktflanke[1,0]
-Reset[1,0]
<
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity |Name| is
    Port ( takt : in std_logic;
           reset : in std_logic;
           q : out std_logic_vector(|Bits-| downto 0));
end |Name|;

architecture Behavioral of |Name| is
signal qi : std_logic_vector(|Bits-| downto 0);
begin
  
  ct: PROCESS (takt,reset)
      BEGIN
        IF reset='|Reset|' THEN qi <= (OTHERS => '0');
	  ELSIF takt'event and takt='|Taktflanke|' 
	        THEN qi <= qi - 1; 
	END IF;
      END PROCESS ct;

  q <= qi;
end Behavioral;
>


#Counter BIN revers with async Reset, sync Load
-Bits[1..36]
-Taktflanke[1,0]
-Reset[1,0]
-Load[1,0]
<
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity |Name| is
    Port ( takt : in std_logic;
           reset : in std_logic;
           load : in std_logic;
           d : in std_logic_vector(|Bits-| downto 0);
           q : out std_logic_vector(|Bits-| downto 0));
end |Name|;

architecture Behavioral of |Name| is
signal qi : std_logic_vector(|Bits-| downto 0);
begin
  
  ct: PROCESS (takt,reset,load,d)
      BEGIN
        IF reset='|Reset|' THEN qi <= (OTHERS => '0');
          ELSIF takt'event and takt='|Taktflanke|' 
	      THEN IF load='|Load|' THEN qi <= d; 
		                    ELSE qi <= qi - 1; END IF;
	END IF;
      END PROCESS ct;

  q <= qi;
end Behavioral;
>


#Counter BIN revers, Enable 
-Bits[1..36]
-Taktflanke[1,0]
-Enable[1,0]
<
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity |Name| is
    Port ( takt : in std_logic;
           enable : in std_logic;
           q : out std_logic_vector(|Bits-| downto 0));
end |Name|;

architecture Behavioral of |Name| is
signal qi : std_logic_vector(|Bits-| downto 0);
begin
  
  ct: PROCESS (takt,enable)
      BEGIN
        IF takt'event and takt='|Taktflanke|' THEN 
	   IF enable = '|enable|' THEN qi <= qi - 1; END IF;
        END IF;
      END PROCESS ct;

  q <= qi;
end Behavioral;
>


#Counter BIN revers with async Reset, Enable
-Bits[1..36]
-Taktflanke[1,0]
-Reset[1,0]
-Enable[1,0]
<
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity |Name| is
    Port ( takt : in std_logic;
           reset : in std_logic;
           enable : in std_logic;
           q : out std_logic_vector(|Bits-| downto 0));
end |Name|;

architecture Behavioral of |Name| is
signal qi : std_logic_vector(|Bits-| downto 0);
begin
  
  ct: PROCESS (takt,reset,enable)
      BEGIN
        IF reset='|Reset|' THEN qi <= (OTHERS => '0');
	  ELSIF takt'event and takt='|Taktflanke|' THEN
	        IF enable = '|enable|' THEN qi <= qi - 1; END IF;
	END IF;
      END PROCESS ct;

  q <= qi;
end Behavioral;
>


#Counter BIN revers with async Reset, sync Load, Enable
-Bits[1..36]
-Taktflanke[1,0]
-Reset[1,0]
-Load[1,0]
-Enable[1,0]
<
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity |Name| is
    Port ( takt : in std_logic;
           reset : in std_logic;
           load : in std_logic;
           enable : in std_logic;
           d : in std_logic_vector(|Bits-| downto 0);
           q : out std_logic_vector(|Bits-| downto 0));
end |Name|;

architecture Behavioral of |Name| is
signal qi : std_logic_vector(|Bits-| downto 0);
begin
  
  ct: PROCESS (takt,reset,load,enable,d)
      BEGIN
        IF reset='|Reset|' THEN qi <= (OTHERS => '0');
          ELSIF takt'event and takt='|Taktflanke|' THEN 
	        IF enable = '|enable|' THEN
                   IF load='|Load|' THEN qi <= d; 
		                    ELSE qi <= qi - 1; END IF;
                END IF;
	END IF;
      END PROCESS ct;

  q <= qi;
end Behavioral;
>


#Counter BIN with Direction
-Bits[1..36]
-Taktflanke[1,0]
-Direction{up}[1,0]
<
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity |Name| is
    Port ( takt : in std_logic;
           dir : in std_logic; 
           q : out std_logic_vector(|Bits-| downto 0));
end |Name|;

architecture Behavioral of |Name| is
signal qi : std_logic_vector(|Bits-| downto 0);
begin
  
  ct: PROCESS (takt,dir)
      BEGIN
        IF takt'event and takt='|Taktflanke|' THEN
	    IF dir = '|Direction{up}|' THEN qi <= qi + 1; 
                         ELSE qi <= qi - 1; END IF;
        END IF;
      END PROCESS ct;

  q <= qi;
end Behavioral;
>


#Counter BIN with async Reset, Direction
-Bits[1..36]
-Taktflanke[1,0]
-Direction{up}[1,0]
-Reset[1,0]
<
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity |Name| is
    Port ( takt : in std_logic;
           reset : in std_logic;
           dir : in std_logic; 
           q : out std_logic_vector(|Bits-| downto 0));
end |Name|;

architecture Behavioral of |Name| is
signal qi : std_logic_vector(|Bits-| downto 0);
begin
  
  ct: PROCESS (takt,reset,dir)
      BEGIN
        IF reset='|Reset|' THEN qi <= (OTHERS => '0');
	  ELSIF takt'event and takt='|Taktflanke|' THEN
	        IF dir = '|Direction{up}|' THEN qi <= qi + 1;
                             ELSE qi <= qi - 1; END IF; 
	END IF;
      END PROCESS ct;

  q <= qi;
end Behavioral;
>


#Counter BIN with async Reset, sync Load, Direction
-Bits[1..36]
-Taktflanke[1,0]
-Direction{up}[1,0]
-Reset[1,0]
-Load[1,0]
<
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity |Name| is
    Port ( takt : in std_logic;
           reset : in std_logic;
           load : in std_logic;
           dir : in std_logic; 
           d : in std_logic_vector(|Bits-| downto 0);
           q : out std_logic_vector(|Bits-| downto 0));
end |Name|;

architecture Behavioral of |Name| is
signal qi : std_logic_vector(|Bits-| downto 0);
begin
  
  ct: PROCESS (takt,reset,dir,load,d)
      BEGIN
        IF reset='|Reset|' THEN qi <= (OTHERS => '0');
          ELSIF takt'event and takt='|Taktflanke|' THEN 
	        IF load='|Load|' THEN qi <= d; 
		            ELSE IF  dir = '|Direction{up}|' THEN qi <= qi + 1; 
                                               ELSE qi <= qi - 1; END IF;  
                END IF;
	END IF;
      END PROCESS ct;

  q <= qi;
end Behavioral;
>


#Counter BIN with Direction, Enable
-Bits[1..36]
-Taktflanke[1,0]
-Direction{up}[1,0]
-Enable[1,0]
<
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity |Name| is
    Port ( takt : in std_logic;
           dir : in std_logic; 
           enable : in std_logic;
           q : out std_logic_vector(|Bits-| downto 0));
end |Name|;

architecture Behavioral of |Name| is
signal qi : std_logic_vector(|Bits-| downto 0);
begin
  
  ct: PROCESS (takt,dir,enable)
      BEGIN
        IF takt'event and takt='|Taktflanke|' THEN
           IF Enable = '|enable|' THEN
 	      IF dir = '|Direction{up}|' THEN qi <= qi + 1; 
                           ELSE qi <= qi - 1; END IF;
           END IF;
        END IF;
      END PROCESS ct;

  q <= qi;
end Behavioral;
>


#Counter BIN with async Reset, Direction, Enable
-Bits[1..36]
-Taktflanke[1,0]
-Direction{up}[1,0]
-Reset[1,0]
-Enable[1,0]
<
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity |Name| is
    Port ( takt : in std_logic;
           reset : in std_logic;
           dir : in std_logic; 
           enable : in std_logic;
           q : out std_logic_vector(|Bits-| downto 0));
end |Name|;

architecture Behavioral of |Name| is
signal qi : std_logic_vector(|Bits-| downto 0);
begin
  
  ct: PROCESS (takt,reset,dir,enable)
      BEGIN
        IF reset='|Reset|' THEN qi <= (OTHERS => '0');
	  ELSIF takt'event and takt='|Taktflanke|' THEN
           IF Enable = '|enable|' THEN
	        IF dir = '|Direction{up}|' THEN qi <= qi + 1;
                             ELSE qi <= qi - 1; END IF; 
           END IF;
	END IF;
      END PROCESS ct;

  q <= qi;
end Behavioral;
>


#Counter BIN with async Reset, sync Load, Direction, Enable
-Bits[1..36]
-Taktflanke[1,0]
-Direction{up}[1,0]
-Reset[1,0]
-Load[1,0]
-Enable[1,0]
<
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity |Name| is
    Port ( takt : in std_logic;
           reset : in std_logic;
           load : in std_logic;
           dir : in std_logic; 
           enable : in std_logic;
           d : in std_logic_vector(|Bits-| downto 0);
           q : out std_logic_vector(|Bits-| downto 0));
end |Name|;

architecture Behavioral of |Name| is
signal qi : std_logic_vector(|Bits-| downto 0);
begin
  
  ct: PROCESS (takt,reset,dir,load,enable,d)
      BEGIN
        IF reset='|Reset|' THEN qi <= (OTHERS => '0');
          ELSIF takt'event and takt='|Taktflanke|' THEN 
           IF Enable = '|enable|' THEN
              IF load='|Load|' THEN qi <= d; 
		          ELSE IF  dir = '|Direction{up}|' THEN qi <= qi + 1; 
                                             ELSE qi <= qi - 1; END IF;  
                               
              END IF;
           END IF; 
	END IF;
      END PROCESS ct;

  q <= qi;
end Behavioral;
>

